@@ -1,4 +1,4 @@
-# Time-stamp: <2016-02-15 14:57:27 Tao Liu>
+# Time-stamp: <2018-10-16 12:02:29 Tao Liu>
 
 """Module Description
 
@@ -190,12 +190,21 @@ def opt_validate ( options ):
         else:
             options.argtxt +=  "# qvalue cutoff = %.2e\n" % (options.qvalue)
 
+    if options.maxgap:
+        options.argtxt += "# The maximum gap between significant sites = %d\n" % options.maxgap
+    else:
+        options.argtxt += "# The maximum gap between significant sites is assigned as the read length/tag size.\n" 
+    if options.minlen:
+        options.argtxt += "# The minimum length of peaks = %d\n" % options.minlen
+    else:
+        options.argtxt += "# The minimum length of peaks is assigned as the predicted fragment length \"d\".\n"
+        
     if options.downsample:
         options.argtxt += "# Larger dataset will be randomly sampled towards smaller dataset.\n"
         if options.seed >= 0:
             options.argtxt += "# Random seed has been set as: %d\n" % options.seed
     else:
-        if options.tolarge:
+        if options.scaleto == "large":
             options.argtxt += "# Smaller dataset will be scaled towards larger dataset.\n"
         else:
             options.argtxt += "# Larger dataset will be scaled towards smaller dataset.\n"
@@ -362,6 +371,8 @@ def opt_validate_filterdup ( options ):
         options.parser = ELANDResultParser
     elif options.format == "BED":
         options.parser = BEDParser
+    elif options.format == "BEDPE":
+        options.parser = BEDPEParser
     elif options.format == "ELANDMULTI":
         options.parser = ELANDMultiParser
     elif options.format == "ELANDEXPORT":
@@ -373,6 +384,11 @@ def opt_validate_filterdup ( options ):
         options.gzip_flag = True
     elif options.format == "BOWTIE":
         options.parser = BowtieParser
+    elif options.format == "BAMPE":
+        options.parser = BAMPEParser
+        options.gzip_flag = True
+    elif options.format == "BEDPE":
+        options.parser = BEDPEParser        
     elif options.format == "AUTO":
         options.parser = guess_parser
     else:
@@ -428,6 +444,11 @@ def opt_validate_randsample ( options ):
         options.gzip_flag = True
     elif options.format == "BOWTIE":
         options.parser = BowtieParser
+    elif options.format == "BAMPE":
+        options.parser = BAMPEParser
+        options.gzip_flag = True
+    elif options.format == "BEDPE":
+        options.parser = BEDPEParser
     elif options.format == "AUTO":
         options.parser = guess_parser
     else:
@@ -612,8 +633,11 @@ def opt_validate_pileup ( options ):
         options.gzip_flag = True
     elif options.format == "BOWTIE":
         options.parser = BowtieParser
-    elif options.format == "AUTO":
-        options.parser = guess_parser
+    elif options.format == "BAMPE":
+        options.parser = BAMPEParser
+        options.gzip_flag = True
+    elif options.format == "BEDPE":
+        options.parser = BEDPEParser
     else:
         logging.error("Format \"%s\" cannot be recognized!" % (options.format))
         sys.exit(1)
