@@ -1,4 +1,4 @@
-# Time-stamp: <2016-02-15 16:12:30 Tao Liu>
+# Time-stamp: <2018-10-15 12:34:16 Tao Liu>
 
 """Description: MACS 2 main executable
 
@@ -73,7 +73,7 @@ def run( args ):
     else:       (treat, control) = load_tag_files_options  (options)
     if control is not None: check_names(treat, control, error)
 
-    info("#1 %s size = %d", tag, options.tsize)
+    info("#1 %s size = %.1f", tag, options.tsize)
     tagsinfo  = "# %s size is determined as %d bps\n" % (tag, options.tsize)
     
     t0 = treat.total
@@ -165,11 +165,11 @@ def run( args ):
             options.d = options.tsize
         else:
             options.d=options.extsize
+            info("#2 Use %d as fragment length" % (options.d))
         if options.shift > 0:
             info("#2 Sequencing ends will be shifted towards 3' by %d bp(s)" % (options.shift))
         elif options.shift < 0:
             info("#2 Sequencing ends will be shifted towards 5' by %d bp(s)" % (options.shift * -1))
-        info("#2 Use %d as fragment length" % (options.d))
         options.scanwindow=2*options.d  # remove the effect of --bw
     else:
         try:
@@ -238,7 +238,7 @@ def run( args ):
             # set options.tocontrol although it would;t matter now
             options.tocontrol = False
         else:
-            if options.tolarge:
+            if options.scaleto == "large":
                 if t1 > c1:
                     # treatment has more tags than control, since tolarge is
                     # true, we will scale control to treatment.
@@ -305,9 +305,9 @@ def run( args ):
     peakdetect.peaks.write_to_xls(ofhd_xls, name = options.name)
     ofhd_xls.close()
     #4.2 peaks in BED
-    if options.log_pvalue:
+    if options.log_pvalue != None:
         score_column = "pscore"
-    elif options.log_qvalue:
+    elif options.log_qvalue != None:
         score_column = "qscore"
     #4.2 peaks in narrowPeak
     if not options.broad:
@@ -381,10 +381,10 @@ def load_frag_files_options ( options ):
         control.finalize()
     else:
         control = None
-    options.info("#1 mean fragment size is determined as %d bp from treatment" % options.tsize)
+    options.info("#1 mean fragment size is determined as %.1f bp from treatment" % options.tsize)
 #    options.info("#1 fragment size variance is determined as %d bp from treatment" % tp.variance)
     if control is not None:
-        options.info("#1 note: mean fragment size in control is %d bp -- value ignored" % control_d)
+        options.info("#1 note: mean fragment size in control is %.1f bp -- value ignored" % control_d)
     return (treat, control)
 
 def load_tag_files_options ( options ):
